// THIS FILE IS GENERATED. ONE SHOULD NOT MODIFY IT
//! This module requires `dataset-og` feature to be enabled.

use crate::dataset_from_path;

dataset_from_path!("../../ontologies/og.nq");
